==> galois-0.3.1.tar.gz: galois-0.3.1/tests/polys/luts/primitive_polys_3.py <==
"""
A module containing LUTs for primitive polynomials over GF(3).

Sage:
    def integer(coeffs, order):
        i = 0
        for d, c in enumerate(coeffs[::-1]):
            i += (c.integer_representation() * order**d)
        return i

    order = 3
    degree = 1
    list_ = []
    R = GF(order, repr="int")["x"]
    for f in R.polynomials(degree):
        # For some reason `is_primitive()` crashes on f(x) = x
        if f.coefficients(sparse=False) == [0, 1]:
            continue
        if f.is_monic() and f.is_primitive():
            list_.append(f.coefficients(sparse=False)[::-1])

    # Sort in lexicographically-increasing order
    if not is_prime(order):
        list_ = sorted(list_, key=lambda item: integer(item, order))

    print(f"PRIMITIVE_POLYS_{order}_{degree} = {list_}")
"""

# LUT items are poly coefficients in degree-descending order

PRIMITIVE_POLYS_3_1 = [
    [1, 1],
]

PRIMITIVE_POLYS_3_2 = [
    [1, 1, 2],
    [1, 2, 2],
]

PRIMITIVE_POLYS_3_3 = [
    [1, 0, 2, 1],
    [1, 1, 2, 1],
    [1, 2, 0, 1],
    [1, 2, 1, 1],
]

PRIMITIVE_POLYS_3_4 = [
    [1, 0, 0, 1, 2],
    [1, 0, 0, 2, 2],
    [1, 1, 0, 0, 2],
    [1, 1, 1, 2, 2],
    [1, 1, 2, 2, 2],
    [1, 2, 0, 0, 2],
    [1, 2, 1, 1, 2],
    [1, 2, 2, 1, 2],
]

PRIMITIVE_POLYS_3_5 = [
    [1, 0, 0, 0, 2, 1],
    [1, 0, 0, 2, 1, 1],
    [1, 0, 1, 0, 1, 1],
    [1, 0, 1, 2, 0, 1],
    [1, 0, 1, 2, 2, 1],
    [1, 0, 2, 1, 0, 1],
    [1, 0, 2, 2, 1, 1],
    [1, 1, 0, 0, 2, 1],
    [1, 1, 0, 1, 0, 1],
    [1, 1, 0, 1, 1, 1],
    [1, 1, 1, 0, 1, 1],
    [1, 1, 1, 1, 2, 1],
    [1, 1, 1, 2, 1, 1],
    [1, 1, 2, 0, 0, 1],
    [1, 1, 2, 1, 1, 1],
    [1, 1, 2, 2, 0, 1],
    [1, 2, 0, 0, 0, 1],
    [1, 2, 0, 0, 1, 1],
    [1, 2, 0, 2, 2, 1],
    [1, 2, 1, 1, 1, 1],
    [1, 2, 2, 0, 2, 1],
    [1, 2, 2, 1, 0, 1],
]

PRIMITIVE_POLYS_3_6 = [
    [1, 0, 0, 0, 0, 1, 2],
    [1, 0, 0, 0, 0, 2, 2],
    [1, 0, 0, 1, 0, 1, 2],
    [1, 0, 0, 2, 0, 2, 2],
    [1, 0, 1, 0, 2, 1, 2],
    [1, 0, 1, 0, 2, 2, 2],
    [1, 0, 1, 1, 0, 2, 2],
    [1, 0, 1, 1, 1, 2, 2],
    [1, 0, 1, 2, 0, 1, 2],
    [1, 0, 1, 2, 1, 1, 2],
    [1, 0, 2, 0, 1, 1, 2],
    [1, 0, 2, 0, 1, 2, 2],
    [1, 0, 2, 1, 1, 1, 2],
    [1, 0, 2, 2, 1, 2, 2],
    [1, 1, 0, 0, 0, 0, 2],
    [1, 1, 0, 1, 0, 0, 2],
    [1, 1, 0, 1, 1, 1, 2],
    [1, 1, 0, 1, 2, 1, 2],
    [1, 1, 0, 2, 2, 0, 2],
    [1, 1, 1, 0, 1, 2, 2],
    [1, 1, 1, 0, 2, 0, 2],
    [1, 1, 1, 1, 0, 1, 2],
    [1, 1, 1, 1, 1, 1, 2],
    [1, 1, 1, 1, 2, 2, 2],
    [1, 1, 1, 2, 2, 2, 2],
    [1, 1, 2, 0, 1, 0, 2],
    [1, 1, 2, 0, 2, 2, 2],
    [1, 1, 2, 1, 0, 1, 2],
    [1, 1, 2, 1, 1, 0, 2],
    [1, 1, 2, 1, 2, 1, 2],
    [1, 1, 2, 2, 2, 0, 2],
    [1, 2, 0, 0, 0, 0, 2],
    [1, 2, 0, 1, 2, 0, 2],
    [1, 2, 0, 2, 0, 0, 2],
    [1, 2, 0, 2, 1, 2, 2],
    [1, 2, 0, 2, 2, 2, 2],
    [1, 2, 1, 0, 1, 1, 2],
    [1, 2, 1, 0, 2, 0, 2],
    [1, 2, 1, 1, 2, 1, 2],
    [1, 2, 1, 2, 0, 2, 2],
    [1, 2, 1, 2, 1, 2, 2],
    [1, 2, 1, 2, 2, 1, 2],
    [1, 2, 2, 0, 1, 0, 2],
    [1, 2, 2, 0, 2, 1, 2],
    [1, 2, 2, 1, 2, 0, 2],
    [1, 2, 2, 2, 0, 2, 2],
    [1, 2, 2, 2, 1, 0, 2],
    [1, 2, 2, 2, 2, 2, 2],
]

==> galois-0.3.4.tar.gz: galois-0.3.4/tests/polys/luts/primitive_polys_3.py <==
"""
A module containing LUTs for primitive polynomials over GF(3).

Sage:
    def integer(coeffs, order):
        i = 0
        for d, c in enumerate(coeffs[::-1]):
            i += (c.integer_representation() * order**d)
        return i

    order = 3
    degree = 1
    list_ = []
    R = GF(order, repr="int")["x"]
    for f in R.polynomials(degree):
        # For some reason `is_primitive()` crashes on f(x) = x
        if f.coefficients(sparse=False) == [0, 1]:
            continue
        if f.is_monic() and f.is_primitive():
            list_.append(f.coefficients(sparse=False)[::-1])

    # Sort in lexicographical order
    if not is_prime(order):
        list_ = sorted(list_, key=lambda item: integer(item, order))

    print(f"PRIMITIVE_POLYS_{order}_{degree} = {list_}")
"""

# LUT items are poly coefficients in degree-descending order

PRIMITIVE_POLYS_3_1 = [
    [1, 1],
]

PRIMITIVE_POLYS_3_2 = [
    [1, 1, 2],
    [1, 2, 2],
]

PRIMITIVE_POLYS_3_3 = [
    [1, 0, 2, 1],
    [1, 1, 2, 1],
    [1, 2, 0, 1],
    [1, 2, 1, 1],
]

PRIMITIVE_POLYS_3_4 = [
    [1, 0, 0, 1, 2],
    [1, 0, 0, 2, 2],
    [1, 1, 0, 0, 2],
    [1, 1, 1, 2, 2],
    [1, 1, 2, 2, 2],
    [1, 2, 0, 0, 2],
    [1, 2, 1, 1, 2],
    [1, 2, 2, 1, 2],
]

PRIMITIVE_POLYS_3_5 = [
    [1, 0, 0, 0, 2, 1],
    [1, 0, 0, 2, 1, 1],
    [1, 0, 1, 0, 1, 1],
    [1, 0, 1, 2, 0, 1],
    [1, 0, 1, 2, 2, 1],
    [1, 0, 2, 1, 0, 1],
    [1, 0, 2, 2, 1, 1],
    [1, 1, 0, 0, 2, 1],
    [1, 1, 0, 1, 0, 1],
    [1, 1, 0, 1, 1, 1],
    [1, 1, 1, 0, 1, 1],
    [1, 1, 1, 1, 2, 1],
    [1, 1, 1, 2, 1, 1],
    [1, 1, 2, 0, 0, 1],
    [1, 1, 2, 1, 1, 1],
    [1, 1, 2, 2, 0, 1],
    [1, 2, 0, 0, 0, 1],
    [1, 2, 0, 0, 1, 1],
    [1, 2, 0, 2, 2, 1],
    [1, 2, 1, 1, 1, 1],
    [1, 2, 2, 0, 2, 1],
    [1, 2, 2, 1, 0, 1],
]

PRIMITIVE_POLYS_3_6 = [
    [1, 0, 0, 0, 0, 1, 2],
    [1, 0, 0, 0, 0, 2, 2],
    [1, 0, 0, 1, 0, 1, 2],
    [1, 0, 0, 2, 0, 2, 2],
    [1, 0, 1, 0, 2, 1, 2],
    [1, 0, 1, 0, 2, 2, 2],
    [1, 0, 1, 1, 0, 2, 2],
    [1, 0, 1, 1, 1, 2, 2],
    [1, 0, 1, 2, 0, 1, 2],
    [1, 0, 1, 2, 1, 1, 2],
    [1, 0, 2, 0, 1, 1, 2],
    [1, 0, 2, 0, 1, 2, 2],
    [1, 0, 2, 1, 1, 1, 2],
    [1, 0, 2, 2, 1, 2, 2],
    [1, 1, 0, 0, 0, 0, 2],
    [1, 1, 0, 1, 0, 0, 2],
    [1, 1, 0, 1, 1, 1, 2],
    [1, 1, 0, 1, 2, 1, 2],
    [1, 1, 0, 2, 2, 0, 2],
    [1, 1, 1, 0, 1, 2, 2],
    [1, 1, 1, 0, 2, 0, 2],
    [1, 1, 1, 1, 0, 1, 2],
    [1, 1, 1, 1, 1, 1, 2],
    [1, 1, 1, 1, 2, 2, 2],
    [1, 1, 1, 2, 2, 2, 2],
    [1, 1, 2, 0, 1, 0, 2],
    [1, 1, 2, 0, 2, 2, 2],
    [1, 1, 2, 1, 0, 1, 2],
    [1, 1, 2, 1, 1, 0, 2],
    [1, 1, 2, 1, 2, 1, 2],
    [1, 1, 2, 2, 2, 0, 2],
    [1, 2, 0, 0, 0, 0, 2],
    [1, 2, 0, 1, 2, 0, 2],
    [1, 2, 0, 2, 0, 0, 2],
    [1, 2, 0, 2, 1, 2, 2],
    [1, 2, 0, 2, 2, 2, 2],
    [1, 2, 1, 0, 1, 1, 2],
    [1, 2, 1, 0, 2, 0, 2],
    [1, 2, 1, 1, 2, 1, 2],
    [1, 2, 1, 2, 0, 2, 2],
    [1, 2, 1, 2, 1, 2, 2],
    [1, 2, 1, 2, 2, 1, 2],
    [1, 2, 2, 0, 1, 0, 2],
    [1, 2, 2, 0, 2, 1, 2],
    [1, 2, 2, 1, 2, 0, 2],
    [1, 2, 2, 2, 0, 2, 2],
    [1, 2, 2, 2, 1, 0, 2],
    [1, 2, 2, 2, 2, 2, 2],
]
